package com.jkcredit.invoice.mapper.customer;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jkcredit.invoice.model.entity.customer.Customer;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 用户信息接口
 * @author mumuxigua
 */
@Repository
public interface CustomerMapper extends BaseMapper<Customer> {

    /**
     * 按照id删除客户信息
     * @param id
     * @return
     */
    int deleteByPrimaryKey(Integer id);

    /**
     * 插入客户信息
     * @param record
     * @return
     */
    @Override
    int insert(Customer record);

    /**
     * 按照提交插入客户信息
     * @param record
     * @return
     */
    int insertSelective(Customer record);

    /**
     * 按照客户id查询客户信息
     * @param id
     * @return
     */
    Customer selectByPrimaryKey(Integer id);

    /**
     * 按照客户名称查询客户信息
     * @param customerName
     * @return
     */
    Customer selectByCustomerName(String customerName);

    /**
     * 按照客户名称查询客户信息 增加锁
     * @param customerName
     * @return
     */
    Customer selectByCustomerNameForLock(String customerName);

    /**
     * 更新客户信息
     * @param record
     * @return
     */
    int updateByPrimaryKeySelective(Customer record);

    /**
     * 按照id更新客户信息
     * @param record
     * @return
     */
    int updateByPrimaryKey(Customer record);

    /**
     * 分页查询客户信息
     * @param page
     * @param customer
     * @return
     */
    IPage<List<Customer>> selectAllByPage(Page page, @Param("customer") Customer customer);

    /**
     * 分页查询正常客户的客户信息
     * @param page
     * @param customer
     * @return
     */
    IPage<List<Customer>> selectAllByPageForNoMoney(Page page, @Param("customer") Customer customer);

    /**
     * 分页查询正常客户的客户信息
     * @param page
     * @param customer
     * @return
     */
    IPage<List<Customer>> selectAllByPageForNoMoneyByZero(Page page, @Param("customer") Customer customer);


    /**
     * 根据客户名称和appSecret 查询客户信息
     * @param customerName
     * @param appSecret
     * @return
     */
    Customer selectByAppKeyAndAppSecret(String customerName, String appSecret);
}