package com.jkcredit.invoice.mapper.waybill;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jkcredit.invoice.model.entity.waybill.SelfCarTrade;
import com.jkcredit.invoice.model.vo.CompanyVo;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 自有车交易接口
 * @author mumuxigua
 */
@Repository
public interface SellCarTradeMapper extends BaseMapper<SelfCarTrade> {

    /**
     * 分页查询自有车交易
     * @param page
     * @param sellCarTrade
     * @return
     */
    IPage<List<SelfCarTrade>> selectAllByPage(Page page, @Param("sellCarTrade") SelfCarTrade sellCarTrade);

    /**
     * 插入自有车交易
     * @param record
     * @return
     */
    @Override
    int insert(SelfCarTrade record);

    /**
     * 更新自有车交易
     * @param record
     * @return
     */
    int updateByPrimaryKey(SelfCarTrade record);

    /**
     * 根据交易id更新自有车交易
     * @param record
     * @return
     */
    int updateByTradeId(SelfCarTrade record);

    /**
     * 根据交易id查询自有车交易列表
     * @param tradeId
     * @return
     */
    List<SelfCarTrade> selectByTradeId(String tradeId);

    /**
     * 根据交易信息查询自有车交易列表
     * @param record
     * @return
     */
    List<SelfCarTrade> selectByCardIdByStatus(SelfCarTrade record);

    /**
     * 根据卡号查询自有车交易列表
     * @param cardId
     * @return
     */
    List<SelfCarTrade> selectByCardId(String cardId);

    /**
     * 根据状态，公司名称查询自有车交易列表
     * @param status
     * @param company
     * @return
     */
    List<SelfCarTrade> selectByStatus(@Param("status") String status, @Param("company") String company);

    /**
     * 根据公司信息更新自有车交易列表
     * @param companyVo
     * @return
     */
    int upDateCompany(CompanyVo companyVo);

}
